import java.util.Scanner;
/**	PreciousStone is a stone, such as a diamond, whose weight
 *  is commonly measured in carats.
 *  The weight can be converted to different units (grams or ounces).
 *  This class has defects intentionally left in place.
 *  @author J. Dalbey
 */
public final class PreciousStone
{
    // Instance fields
    private double caratWt;  // the stone's weight in carats

    /** Construct a precious stone.
     * @param weight the weight of the stone in carats.
     */
    public PreciousStone(double weight)
    {
        // Force any negative weight to be zero
        if (weight > 0) 
        {
            caratWt = weight;
        }
        else
        {
            caratWt = 0;
        }
    }
    
    /** Converts a measurement in carats to milligrams.
     * @return the stone's weight in milligrams
     */
    public double toMilligrams()
    {
        double conversionFactor = 200.0;   // 1 carat = 200 mg
        return conversionFactor * caratWt;
    }

    /** Converts a measurement in carats to grams.
     * @return the stone's weight in grams
     */
    public double toGrams()
    {
        double conversionFactor = 1000.0;  // 1000 mg = 1 gram
        return conversionFactor * toMilligrams();
    }

    /** Converts a measurement in carats to ounces.
     * @return the stone's weight in ounces
     */
    public double toOunces()
    {
        double KgPerG = 0.001;    // 1000 G = 1 Kg
        double LbPerKg = 2.20460;  // 1Kg = 2.2Lb
        double OzPerLb = 16.0;     // 1Lb = 16Oz
        return OzPerLb * LbPerKg * KgPerG * toGrams();
    }

    /** Convenience method to display the stone weight 
     * in all available units. 
     */
    public void displayWeight()
    {
        System.out.println("This stone weighs " + toMilligrams() + " milligrams.");
        System.out.println("This stone weighs " + toGrams() + " grams.");
        System.out.println("This stone weighs " + toOunces() + " ounces.");
    }
    
    /** A local main for unit testing.
     *  @param args not used
     */
	public static void main(String args[]) 
	{
	    // Create a scanner to read from the standard input
        Scanner console = new Scanner(System.in);
        // Continue reading until End Of File
        do
        {
            // Prompt the user for the weight        
            System.out.println("Enter the weight of a stone in carats, e.g., 0.26");
            // Obtain the number from the user
            double weight = console.nextDouble();
		    // Create an instance of a piece of stone object.
		    PreciousStone  aStone = new PreciousStone(weight);
		    //Display the result in a meaningful way.
		    aStone.displayWeight();
        } while (console.hasNextDouble());
	}
     
} 

